About rampedpyrox
=================
``rampedpyrox`` is a Python package for analyzing experimental kinetic data and accompanying chemical/isotope compositional information. ``rampedpyrox`` is especially suited for analyzing results from ramped-temperature instruments such as Ramped PyrOx, RockEval, pyrolysis gc (pyGC), thermogravimitry (TGA), etc. This package converts time-series mass observations into rate/activation energy (E) distributions using a selection of reactive continuum models, including the Distributed Activation Energy Model (DAEM) for non-isothermal data. Additionally, this package correlates modelled rate/E data with measured isotope compositional data and corrects isotopes for kinetic fractionation, if appropriate.

This package was created as a supplement to J.D. Hemingway's PhD thesis awarded by the MIT/WHOI Joint Program in Oceanography (December 2016), `which can be found here <https://github.com/FluvialSeds/thesis_master>`_.

Package Information
-------------------
:Authors:
  Jordon D. Hemingway (jordon_hemingway@harvard.edu)

:Version:
  0.1.3

:Release:
  26 January 2017

:License:
  GNU GPL v3 (or greater)

:url:
  http://github.com/FluvialSeds/rampedpyrox

How to Cite
-----------
When analyzing data with ``rampedpyrox`` to be used in a peer-reviewed
journal, please cite this package as:

* J.D. Hemingway. *rampedpyrox*: open-source tools for thermoanalytical data analysis, 2016-, http://github.com/FluvialSeds/rampedpyrox [online; accessed |date|]

Additionally, please cite the following peer-reviewed manuscript describing the deveopment of the package and Ramped PyrOx data treatment:

* J.D. Hemingway et al. **(in prep)** An inverse model for relating organic carbon thermal reactivity and isotope composition using Ramped PyrOx.

If using Ramped PyrOx data generated by the NOSAMS instrument, the following manuscript contains relevant information regarding blank carbon composition, isotope mass balance, and the magnitude of the kinetic isotope effect:

* J.D. Hemingway et al. (2017) Assessing the blank carbon contribution, isotope mass balance, and kinetic isotope fractionation of the ramped pyrolysis/oxidation instrument at NOSAMS. *Radiocarbon*, **in press**.


Documentation
-------------
The documentation for the latest release, including detailed package references as well as a comprehensive walkthrough for analyzing Ramped PyrOx data, is available at:

	http://rampedpyrox.readthedocs.io

Package features
----------------
``rampedpyrox`` currently contains the following features relevant to non-isothermal kinetic analysis:

* Stores and plots thermogram data

* Performs first-order DAEM inverse model to estimate activation energy distributions, p\ :sub:`0`\ (E)

  * Regularizes ("smoothes") p\ :sub:`0`\ (E) using Tikhonov Regularization

    * Automated or user-defined regularization value

* Calculates subset of p\ :sub:`0`\ (E) contained in each RPO collection fraction

  * Automatically blank-corrects inputted isotope values using any known blank carbon composition

  * Corrects measured :sup:`13`\ C/:sup:`12`\ C ratios for the kinetic isotope effect (KIE) during heating

* Calculates and stores model performance metrics and goodness of fit 
  statistics

* Generates plots of thermograms, p\ :sub:`0`\ (E), and E vs. isotope values for each RPO fraction

* Allows for forward-modeling of any arbitrary time-temperature history, *e.g.* to determine the decomposition rates and isotope fractionation during geologic organic carbon matruation

Future Additions
~~~~~~~~~~~~~~~~
Future versions of ``rampedpyrox`` will aim to include:

* Better support for isothermal experimental conditions

* Non-first-order kinetic models


How to Obtain
=============

Source code can be directly downloaded from GitHub:

	http://github.com/FluvialSeds/rampedpyrox

Binaries can be installed through the Python package index::

	$ pip install rampedpyrox

License
=======
This product is licensed under the GNU GPL license, version 3 or greater.

Bug Reports
===========
This software is still in active deveopment. Please report any bugs directly to me at:

	jordon_hemingway@harvard.edu


.. |date| date::